<?php

namespace apexl\Io\modules\display\components;

class FilterForm extends FormComponent
{
    public function __construct()
    {
        parent::__construct();
        $this->addProperty('buildSubmitOnly', true);
        $this->addProperty('persistFilters', true);
    }

    public function isShared()
    {
        $this->addProperty('isShared', true);
        return $this;
    }
}
