<?php

declare(strict_types=1);

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

final class FilterableMenus extends componentEntity
{
    private const string PROP__MENUS = 'menus';
    private const string PROP__FILTERABLE = 'filterable';

    public function __construct(array $menus, bool $filterable = false)
    {
        parent::__construct();

        $this->addProperty(self::PROP__MENUS, $menus);
        $this->addProperty(self::PROP__FILTERABLE, $filterable);
    }
}