<?php

namespace apexl\Io\modules\display\components\form;

use apexl\Io\modules\component\entities\componentEntity;

class InputField extends BaseField
{
    
    public function __construct($fieldName)
    {
        parent::__construct($fieldName);
        $this->setName('InputField');
        $this->setFieldName($fieldName);
        $this->setInputType('text');
    }
    
    public function setInputType(string $type)
    {
        $this->addProperty('inputType', $type);
        return $this;
    }

    public function setPlaceholder(string $text)
    {
        $this->addProperty('placeholder', $text);
        return $this;
    }

}
